function CPlayer (oParentContainer) {
    var _oPlayer;
    var _iVelocity = 0;
    var _bIsFlipped = false;
    var _bShield;
    var iPlayerState = 0;  // Player State: 0 = idle/walking ; 1 = hit ; 2 = get bonus ; 3 = dead
    
    this._init = function(oParentContainer) {
        _bShield = false;

        var oData = {   
                images: [s_oSpriteLibrary.getSprite("player")], 
                framerate: 30,
                // width, height & registration point of each sprite
                frames: {width: 113, height: 131, regX: 113/2, regY: 131}, 
                animations: { idle        : [0, 8, true, 0.5], 
                              walk        : [9, 23],
                              hit         : [24, 27, false, 0.3],
                              walk_shield : [28, 42],
                              death       : [43, 68, true],
                              idle_shield : [69, 69] }
            };
        var oSpriteSheet = new createjs.SpriteSheet(oData);

        _oPlayer = createSprite(oSpriteSheet, "idle", 113/2, 131, 113, 131);
        _oPlayer.width = 131;
        _oPlayer.x = CANVAS_WIDTH / 2;
        _oPlayer.y = CANVAS_HEIGHT / 2 + 360;
        oParentContainer.addChild(_oPlayer);
    };

    this.flipSprite = function(iDir){
        if(iDir === GOING_LEFT){
            _oPlayer.scaleX -= 2; 
        }else if(iDir === GOING_RIGHT){
            _oPlayer.scaleX += 2; 
        }
    };

    this.gameOver = function() {
        iPlayerState = 3;
    };
    
    //MOVE THE PLAYER
    this._movePlayer = function(iForceDirection, iAcceleration){
        _iVelocity += (iAcceleration*iForceDirection);
        
        if ( _iVelocity < 0 ){
            if(_iVelocity < -PLAYER_SPD_MAX){
                _iVelocity = -PLAYER_SPD_MAX;
            }
            if(!_bIsFlipped){
                _bIsFlipped = true;
                this.flipSprite(GOING_LEFT);
            }
        } else if ( _iVelocity > 0 ){
            if(_iVelocity > PLAYER_SPD_MAX){
                _iVelocity = PLAYER_SPD_MAX;
            }
            if(_bIsFlipped){
                _bIsFlipped = false;
                this.flipSprite(GOING_RIGHT);
            }
        }

        this.addSpeedToPlayer(_iVelocity);
        
        if(_iVelocity > 0){
            _iVelocity -= PLAYER_DECELERATION;
            if(_iVelocity < 0){
                _iVelocity = 0;
            }
        } else if(_iVelocity < 0){
            _iVelocity += PLAYER_DECELERATION;
            if(_iVelocity > 0){
                _iVelocity = 0;
            }
        }
        if(this.getX() > CANVAS_WIDTH - s_iOffsetX){
            this.setPos(0);
        } else if(this.getX() < 0 + s_iOffsetX){
            this.setPos(CANVAS_WIDTH);
        }
        
        if (iPlayerState === 0) {
            s_oPlayer.backToIdleAnimation();
        };
    };
    
    this.backToIdleAnimation = function() {
        // Change animations according to necessity
        if (_bShield === false) {
            if ( _iVelocity !== 0 ) {
                if (_oPlayer.currentAnimation !== "walk") {
                    _oPlayer.gotoAndPlay("walk"); };
            } else if ( _iVelocity <= 0 ) {
                if (_oPlayer.currentAnimation !== "idle") {
                    _oPlayer.gotoAndPlay("idle"); };
            };
        } else if (_bShield === true) {
            if ( _iVelocity !== 0 ) {
                if (_oPlayer.currentAnimation !== "walk_shield") {
                    _oPlayer.gotoAndPlay("walk_shield"); };
            } else if ( _iVelocity <= 0 ) {
                if (_oPlayer.currentAnimation !== "idle_shield") {
                    _oPlayer.gotoAndPlay("idle_shield"); };
            };
        };
    };
    
    this.isShield = function() {
        return _bShield;
    };

    this.playerIsHit = function() {
        if (_bShield === true) {
            playSound("stone_on_shield",1,0);
        } else {
            playSound("hit",1,0);
            iPlayerState = 1;
            s_oGame.subtractLife();
            _oPlayer.gotoAndPlay("hit");
            
            if (_oPlayer.currentAnimation === "hit") {
                _oPlayer.on("animationend", s_oPlayer.animationHitChange);
            }
        };
    };
    
    this.animationHitChange = function() {
        if (iPlayerState === 3) {
            _oPlayer.gotoAndPlay("death");
        } else {
            iPlayerState = 0;
            s_oPlayer.backToIdleAnimation();
        };
    };
    
    this.playerTakeShield = function() {
        if (_bShield === false) {
            playSound("power_up",0.7,0);
            _bShield = true;
            s_oInterface.toggleShieldIcon(_bShield);
        };
    };

    this.removeShield = function() {
        _bShield = false;
        s_oInterface.toggleShieldIcon(_bShield);
    };

    this.playerTakeHealth = function() {
        playSound("power_up",0.7,0);
        for (var i = 0; i < HEALTH_POINTS; i++) {
            s_oGame.addLife();
        }
    };

    this.playerTakeCoin = function() {
        playSound("money",0.7,0);
        for (var i = 0; i < COIN_POINTS; i++) {
            s_oGame.addScore();
        }
    };

    this.addSpeedToPlayer = function(iXToAdd){
        _oPlayer.x += iXToAdd;
    };

    this.setPos = function(newX){
        _oPlayer.x = newX;
    };

    this.getX = function(){
        return _oPlayer.x;
    };

    this.getY = function(){
        return _oPlayer.y;
    };

    this.pauseAnimation = function() {
        _oPlayer.stop();
    };
    
    this.resumeAnimation = function() {
        _oPlayer.play();
    };

    this.moveLeft = function() {
        if (iPlayerState <= 2) {
            _bIsFlipped = true;
            this._movePlayer();
        };
    };

    this.moveRight = function() {
        if (iPlayerState <= 2) {
            _bIsFlipped = false;
            this._movePlayer();
        };
    };

    s_oPlayer = this;
    
    this._init(oParentContainer);
};

var s_oPlayer;